@@ -1,14 +1,14 @@
+import collections.abc
 from pathlib import Path
 from typing import Iterable, Union
 
-import PIL
 import numpy as np
-import collections.abc
+from PIL.Image import Image
 
 array = np.ndarray
 path_like = Union[Path, str]
 array_like = Union[np.ndarray, Iterable, int, float]
-image_like = Union[np.ndarray, PIL.Image.Image]
+image_like = Union[np.ndarray, Image]
 
 
 Sequence = collections.abc.Sequence
